MinimalArchaeology = {}

MinimalArchaeology['skill'] = {}	 -- Store information about the players skill
MinimalArchaeology['artifacts'] = {} -- Store information about current artifacts
MinimalArchaeology['barlinks'] = {1,2,3,4,5,6,7,8,9,10} -- Store information about bar links
MinimalArchaeology['ArtifactBars'] = {} -- References for the artifact bars

MinimalArchaeologyOptions = {} -- Store options
MinimalArchaeologyHideOptions = {} -- Store Artifact Hide specific options
MinimalArchaeologyArtifactOptions = {} -- Store Artifact specific options

SLASH_MINIMALARCHAEOLOGY1 = "/minarch"
SlashCmdList["MINIMALARCHAEOLOGY"] = function(msg, editBox)
    MinimalArchaeologyFrame:Show();
	MinimalArchaeologyOptions['HideFrame'] = false;
end

function MinimalArchaeology:OnLoad(self)
	-- Register Events
	MinimalArchaeologyFrame:RegisterForDrag("LeftButton")
	
	--MinimalArchaeologyFrame:RegisterEvent("ARTIFACT_UPDATE"); -- Will need this later for keystones
	
	MinimalArchaeologyFrame:RegisterEvent("ARTIFACT_HISTORY_READY");
	MinimalArchaeologyFrame:RegisterEvent("ARTIFACT_COMPLETE");
	MinimalArchaeologyFrame:RegisterEvent("ARTIFACT_DIG_SITE_UPDATED");
	MinimalArchaeologyFrame:RegisterEvent("CURRENCY_DISPLAY_UPDATE");
	MinimalArchaeologyFrame:RegisterEvent("SKILL_LINES_CHANGED");
	
	MinimalArchaeologyFrame:RegisterEvent("BAG_UPDATE");	-- Might need this later
	
	MinimalArchaeologyFrame:RegisterEvent("ADDON_LOADED");  -- Apply SavedVariables
	
	for i=1,10 do -- Artifact Arrays
		MinimalArchaeology['artifacts'][i] = {};
		--MinimalArchaeologyOptions['artifacts'][i] = {}; 
	end
	
	-- Set Frames
	MinimalArchaeology['ArtifactBars'][1] = MinimalArchaeologyFrameStatusBar1;
	MinimalArchaeology['ArtifactBars'][2] = MinimalArchaeologyFrameStatusBar2;
	MinimalArchaeology['ArtifactBars'][3] = MinimalArchaeologyFrameStatusBar3;
	MinimalArchaeology['ArtifactBars'][4] = MinimalArchaeologyFrameStatusBar4;
	MinimalArchaeology['ArtifactBars'][5] = MinimalArchaeologyFrameStatusBar5;
	MinimalArchaeology['ArtifactBars'][6] = MinimalArchaeologyFrameStatusBar6;
	MinimalArchaeology['ArtifactBars'][7] = MinimalArchaeologyFrameStatusBar7;
	MinimalArchaeology['ArtifactBars'][8] = MinimalArchaeologyFrameStatusBar8;
	MinimalArchaeology['ArtifactBars'][9] = MinimalArchaeologyFrameStatusBar9;
	MinimalArchaeology['ArtifactBars'][10] = MinimalArchaeologyFrameStatusBar10;
	
	ChatFrame1:AddMessage("Minimal Archaeology Loaded!");
end

function MinimalArchaeology:OnEvent(event, ...)
	if (event == "ADDON_LOADED" and MinimalArchaeology ~= nil) then
		if (MinimalArchaeologyOptions['MinimapPos'] ~= nil) then
			MinimalArchaeology:MinimapButtonReposition();
		else
			MinimalArchaeologyOptions['MinimapPos'] = 45;
		end
		
		if (MinimalArchaeologyOptions['HideFrame'] == nil) then
			MinimalArchaeologyOptions['HideFrame'] = false;
		else
			if (MinimalArchaeologyOptions['HideFrame'] == true) then
				MinimalArchaeologyFrame:Hide();
			end
		end
		
		if (MinimalArchaeologyOptions['HideMinimap'] == nil) then
			MinimalArchaeologyOptions['HideMinimap'] = false;
		else
			if (MinimalArchaeologyOptions['HideMinimap'] == true) then
				MinimalArchaeologyMinimapButton:Hide();
			end
		end
		
		if (MinimalArchaeologyOptions['DisableSound'] == nil) then
			MinimalArchaeologyOptions['DisableSound'] = false;
		end
		
		for i=0,10 do
			if (MinimalArchaeologyHideOptions[i] == nil) then
				MinimalArchaeologyHideOptions[i] = {}; 
				MinimalArchaeologyHideOptions[i]['Hide'] = false;
			end
			
			if (MinimalArchaeologyArtifactOptions[i] == nil) then
				MinimalArchaeologyArtifactOptions[i] = {}; 
				MinimalArchaeologyArtifactOptions[i]['AlwaysUseKeystone'] = false;
			end
		end
		
		MinimalArchaeology:OptionSetCheckBoxes();
	end

	MinimalArchaeology:UpdateMinArchRankBar();
end

function MinimalArchaeology:UpdateMinArchSkill()	-- Update archaeology skill information
	local _, _, arch = GetProfessions();
	if arch then
		local name, _, rank, maxRank = GetProfessionInfo(arch);
		MinimalArchaeology['skill']['name'] = name;
		MinimalArchaeology['skill']['rank'] = rank;
		MinimalArchaeology['skill']['maxRank'] = maxRank;
	else
		MinimalArchaeology['skill']['name'] = "Archaeology";
		MinimalArchaeology['skill']['rank'] = 0;
		MinimalArchaeology['skill']['maxRank'] = 0;
	end
end

function MinimalArchaeology:UpdateMinArchSkillBar(SkillBar)	-- Update a status bar to represent the skill information
	local skill = MinimalArchaeology['skill'];
	
	SkillBar:SetMinMaxValues(0, skill['maxRank']);
	SkillBar:SetValue(skill['rank']);
	SkillBar.text:SetText(skill['name'].." "..skill['rank'].."/"..skill['maxRank']);
end

function MinimalArchaeology:UpdateMinArchArtifact(ArtifactIndex)	-- Update artifact details, only keep relevant data
	local numArtifacts = GetNumArtifactsByRace(ArtifactIndex);
	local RaceName, _, _, RaceitemID = GetArchaeologyRaceInfo(ArtifactIndex);
	
	MinimalArchaeology['artifacts'][ArtifactIndex]['race'] = RaceName;
	MinimalArchaeology['artifacts'][ArtifactIndex]['raceitemid'] = RaceitemID;
	
	if (MinimalArchaeology['artifacts'][ArtifactIndex]['appliedKeystones'] == nil) then
		MinimalArchaeology['artifacts'][ArtifactIndex]['appliedKeystones'] = 0;
	end
	
	if (numArtifacts == 0) then	-- The Artifact hasn't been discovered
		MinimalArchaeology['artifacts'][ArtifactIndex]['numKeystones'] = 0;
		MinimalArchaeology['artifacts'][ArtifactIndex]['progress'] = 0;
		MinimalArchaeology['artifacts'][ArtifactIndex]['modifier'] = 0;
		MinimalArchaeology['artifacts'][ArtifactIndex]['total'] = 0;
		MinimalArchaeology['artifacts'][ArtifactIndex]['canSolve'] = false;
		MinimalArchaeology['artifacts'][ArtifactIndex]['canSolvePrev'] = false;
	else
		SetSelectedArtifact(ArtifactIndex);
		
		local availablekeystones = 0;
		if (MinimalArchaeologyArtifactOptions[ArtifactIndex] ~= nil) then
			if (MinimalArchaeologyArtifactOptions[ArtifactIndex]['AlwaysUseKeystone']) then
				MinimalArchaeology['artifacts'][ArtifactIndex]['appliedKeystones'] = 4;
			end
			
			for i=1, MinimalArchaeology['artifacts'][ArtifactIndex]['appliedKeystones'] do
				SocketItemToArtifact();
				
				if (ItemAddedToArtifact(i)) then
					availablekeystones = availablekeystones + 1;
				end
			end	
		end
		MinimalArchaeology['artifacts'][ArtifactIndex]['appliedKeystones'] = availablekeystones;
		
		
		local Name, Description, Rarity, Icon, SpellDescription, NumKeystones = GetSelectedArtifactInfo();
		local Progress, Modifier, Total = GetArtifactProgress();
		
		MinimalArchaeology['artifacts'][ArtifactIndex]['numKeystones'] = NumKeystones;
		MinimalArchaeology['artifacts'][ArtifactIndex]['progress'] = Progress;
		MinimalArchaeology['artifacts'][ArtifactIndex]['modifier'] = Modifier;
		MinimalArchaeology['artifacts'][ArtifactIndex]['total'] = Total;
		MinimalArchaeology['artifacts'][ArtifactIndex]['canSolvePrev'] = MinimalArchaeology['artifacts'][ArtifactIndex]['canSolve'];
		MinimalArchaeology['artifacts'][ArtifactIndex]['canSolve'] = CanSolveArtifact();
		MinimalArchaeology['artifacts'][ArtifactIndex]['name'] = Name;
		MinimalArchaeology['artifacts'][ArtifactIndex]['rarity'] = Rarity;
		MinimalArchaeology['artifacts'][ArtifactIndex]['description'] = Description;
		MinimalArchaeology['artifacts'][ArtifactIndex]['spelldescription'] = SpellDescription;

	end	
	
	
end

function MinimalArchaeology:UpdateMinArchArtifactBar(ArtifactIndex, ArtifactBar)
	local artifact = MinimalArchaeology['artifacts'][ArtifactIndex];
	local keyStars = "";
	local RuneName, _, _, _, _, _, _, _, _, runeStoneIconPath = GetItemInfo(artifact['raceitemid']);
	
	ArtifactBar:SetMinMaxValues(0, artifact['total']);
	ArtifactBar:SetValue(min(artifact['progress']+artifact['modifier'], artifact['total']));
	
	ArtifactBar.keystone.icon:SetTexture(runeStoneIconPath);
	if (artifact['appliedKeystones'] == 0) then
		ArtifactBar.keystone.icon:SetAlpha(0.1);
		ArtifactBar.keystone.text:SetText("");
	else
		ArtifactBar.keystone.icon:SetAlpha((artifact['appliedKeystones']/artifact['numKeystones']));
		ArtifactBar.keystone.text:SetText(artifact['appliedKeystones']);
	end	
	
	if (artifact['numKeystones'] > 0 and artifact['total'] > 0) then
		ArtifactBar.keystone:Show();
		ArtifactBar.keystone.icon:Show();
		for i=1,artifact['numKeystones'] do
			keyStars = "*"..keyStars;
		end
	else
		ArtifactBar.keystone:Hide();
	end
	
	if (artifact['modifier'] > 0) then
		ArtifactBar.text:SetText(keyStars..artifact['race'].." (+"..artifact['modifier']..") "..(artifact['progress']+artifact['modifier']).."/"..artifact['total']);
	else
		ArtifactBar.text:SetText(keyStars..artifact['race'].." "..artifact['progress'].."/"..artifact['total']);
	end
	
	if (artifact['canSolve']) then
		if (MinimalArchaeologyOptions['DisableSound'] == false and artifact['canSolvePrev'] ~= artifact['canSolve']) then
			PlaySoundFile("Sound\\interface\\MapPing.wav")
			artifact['canSolvePrev'] = artifact['canSolve'];
		end
		ArtifactBar.solveButton:Enable();
	else
		ArtifactBar.solveButton:Disable();
	end	
end

function MinimalArchaeology:MinArchSolve(BarIndex)
	SetSelectedArtifact(MinimalArchaeology['barlinks'][BarIndex]);
	
	for i=1, MinimalArchaeology['artifacts'][MinimalArchaeology['barlinks'][BarIndex]]['appliedKeystones'] do
		SocketItemToArtifact();
	end	
	
	MinimalArchaeology['artifacts'][MinimalArchaeology['barlinks'][BarIndex]]['appliedKeystones'] = 0;
	
	SolveArtifact();
end

function MinimalArchaeology:UpdateMinArchRankBar()
	MinimalArchaeology:UpdateMinArchSkill();
	MinimalArchaeology:UpdateMinArchSkillBar(MinimalArchaeologyFrameSkillBar);
	
	local ActiveBarIndex = 0;
	
	for i=1,10 do
		MinimalArchaeology:UpdateMinArchArtifact(i); -- Update each artifact
		
		local artifact = MinimalArchaeology['artifacts'][i];
		local options = MinimalArchaeologyHideOptions[i];
		if (artifact['total'] > 0 and options['Hide'] == false) then
			ActiveBarIndex = ActiveBarIndex + 1;
			MinimalArchaeology:UpdateMinArchArtifactBar(i,MinimalArchaeology['ArtifactBars'][ActiveBarIndex]);
			MinimalArchaeology['ArtifactBars'][ActiveBarIndex]:Show();
			MinimalArchaeology['barlinks'][ActiveBarIndex] = i;
		end
	end
	
	local MinArchFrameHeight = 310;
	
	for i=ActiveBarIndex+1, 10 do
		MinimalArchaeology['ArtifactBars'][i]:Hide();
		MinArchFrameHeight = MinArchFrameHeight - 25;
	end
	
	MinimalArchaeologyFrame:SetHeight(MinArchFrameHeight);
	
end

function MinimalArchaeology:ArtifactToolTip(BarIndex)
	local artifact = MinimalArchaeology['artifacts'][MinimalArchaeology['barlinks'][BarIndex]];
	GameTooltip:SetOwner(MinimalArchaeology['ArtifactBars'][BarIndex], "ANCHOR_BOTTOMRIGHT");
	if (artifact['rarity'] == 1) then
		GameTooltip:AddLine(artifact['name'], 0, 0.4, 0.8, 1);
	else
		GameTooltip:AddLine(artifact['name'], GRAY_FONT_COLOR.r, GRAY_FONT_COLOR.g, GRAY_FONT_COLOR.b, 1);
	end
	GameTooltip:AddLine(artifact['description'], 1.0, 1.0, 1.0, 1);
	GameTooltip:AddLine(artifact['spelldescription'], NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b, 1);
	GameTooltip:Show();
end

function MinimalArchaeology:KeystoneClick(self, button, down)
	local artifactIndex = MinimalArchaeology['barlinks'][self:GetID()];
	local numofappliedkeystones = MinimalArchaeology['artifacts'][artifactIndex]['appliedKeystones'];
	local numoftotalkeystones = MinimalArchaeology['artifacts'][artifactIndex]['numKeystones'];
	
	if (button == "LeftButton") then
		if (numofappliedkeystones < numoftotalkeystones) then
			 MinimalArchaeology['artifacts'][artifactIndex]['appliedKeystones'] = numofappliedkeystones + 1;
		end
	elseif (button == "RightButton") then
		if (numofappliedkeystones > 0) then
			 MinimalArchaeology['artifacts'][artifactIndex]['appliedKeystones'] = numofappliedkeystones - 1;
		end
	end
		
	MinimalArchaeology:UpdateMinArchArtifact(artifactIndex);
	MinimalArchaeology:UpdateMinArchArtifactBar(artifactIndex,MinimalArchaeology['ArtifactBars'][self:GetID()]);
	
end

-- Minimap Functions

function MinimalArchaeology:MinimapButtonReposition()
	MinimalArchaeologyMinimapButton:SetPoint("TOPLEFT","Minimap","TOPLEFT",52-(80*cos(MinimalArchaeologyOptions.MinimapPos)),(80*sin(MinimalArchaeologyOptions.MinimapPos))-52)
end

-- Only while the button is dragged this is called every frame
function MinimalArchaeology:MinimapButtonDraggingFrameOnUpdate()

	local xpos,ypos = GetCursorPosition()
	local xmin,ymin = Minimap:GetLeft(), Minimap:GetBottom()

	xpos = xmin-xpos/UIParent:GetScale()+70 -- get coordinates as differences from the center of the minimap
	ypos = ypos/UIParent:GetScale()-ymin-70

	MinimalArchaeologyOptions.MinimapPos = math.deg(math.atan2(ypos,xpos)) -- save the degrees we are relative to the minimap center
	MinimalArchaeology:MinimapButtonReposition() -- move the button
end

-- Put your code that you want on a minimap button click here.
function MinimalArchaeology:MinimapButtonOnClick()
	if (MinimalArchaeologyFrame:IsVisible()) then
		MinimalArchaeologyFrame:Hide();
		MinimalArchaeologyOptions['HideFrame'] = true;
	else
		MinimalArchaeologyFrame:Show();
		MinimalArchaeologyOptions['HideFrame'] = false;
	end
end

-- Options Panel Functions

function MinimalArchaeology:OptionsLoad()

	MinimalArchaeologyOptionPanel.AddonName:SetText("Minimal Archaeology");
	MinimalArchaeologyOptionPanel.AddonVersion:SetText(GetAddOnMetadata("MinimalArchaeology", "Version"));
	MinimalArchaeologyOptionPanel.name = "Minimal Archaeology";
	MinimalArchaeologyOptionPanel.okay = MinimalArchaeologyOptionPanel:Hide();
	MinimalArchaeologyOptionPanel.cancel = MinimalArchaeologyOptionPanel:Hide();
	InterfaceOptions_AddCategory(MinimalArchaeologyOptionPanel);
end

function MinimalArchaeology:HideOptionToolTip(HideID)
	GameTooltip:SetOwner(MinimalArchaeologyOptionPanel.hideArtifact, "ANCHOR_TOPLEFT");
	GameTooltip:AddLine("Hide the "..MinimalArchaeology['artifacts'][HideID]['race'].." artifact bar even if it has been discovered.", 1.0, 1.0, 1.0, 1);
	GameTooltip:Show();
end

function MinimalArchaeology:UseKeystoneOptionToolTip(UseKeystoneID)
	local RuneName, _, _, _, _, _, _, _, _, _ = GetItemInfo(MinimalArchaeology['artifacts'][UseKeystoneID]['raceitemid']);
	local RaceName = MinimalArchaeology['artifacts'][UseKeystoneID]['race'];
	
	GameTooltip:SetOwner(MinimalArchaeologyOptionPanel.useKeystones, "ANCHOR_TOPLEFT");
	GameTooltip:AddLine("Always use all available "..RuneName.."s to solve "..RaceName.." artifacts.", 1.0, 1.0, 1.0, 1);
	GameTooltip:Show();
end

function MinimalArchaeology:MiscOptionToolTip(MiscID)
	GameTooltip:SetOwner(MinimalArchaeologyOptionPanel.miscOptions, "ANCHOR_TOPLEFT");
	
	if (MiscID == 1) then
		GameTooltip:AddLine("Hide the Minimap button.", 1.0, 1.0, 1.0, 1);
	elseif (MiscID == 2) then
		GameTooltip:AddLine("Disable the sound that is played when an artifact can be solved.", 1.0, 1.0, 1.0, 1);
	end
	
	GameTooltip:Show();
end

function MinimalArchaeology:HideOptionToggle()

	if (MinimalArchaeologyOptionPanel.hideArtifact.hide1:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[1]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[1]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide2:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[2]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[2]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide3:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[3]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[3]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide4:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[4]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[4]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide5:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[5]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[5]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide6:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[6]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[6]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide7:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[7]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[7]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide8:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[8]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[8]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide9:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[9]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[9]['Hide'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.hideArtifact.hide10:GetChecked() == 1) then
        MinimalArchaeologyHideOptions[10]['Hide'] = true;
    else
        MinimalArchaeologyHideOptions[10]['Hide'] = false;
    end
	
	MinimalArchaeology:UpdateMinArchRankBar();
end

function MinimalArchaeology:UseKeystoneOptionToggle()

	if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone1:GetChecked() == 1) then
        MinimalArchaeologyArtifactOptions[1]['AlwaysUseKeystone'] = true;
    else
        MinimalArchaeologyArtifactOptions[1]['AlwaysUseKeystone'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone2:GetChecked() == 1) then
        MinimalArchaeologyArtifactOptions[2]['AlwaysUseKeystone'] = true;
    else
        MinimalArchaeologyArtifactOptions[2]['AlwaysUseKeystone'] = false;
    end
	
	--if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone3:GetChecked() == 1) then
    --    MinimalArchaeologyArtifactOptions[3]['AlwaysUseKeystone'] = true;
    --else
    --    MinimalArchaeologyArtifactOptions[3]['AlwaysUseKeystone'] = false;
    --end
	
	if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone4:GetChecked() == 1) then
        MinimalArchaeologyArtifactOptions[4]['AlwaysUseKeystone'] = true;
    else
        MinimalArchaeologyArtifactOptions[4]['AlwaysUseKeystone'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone5:GetChecked() == 1) then
        MinimalArchaeologyArtifactOptions[5]['AlwaysUseKeystone'] = true;
    else
        MinimalArchaeologyArtifactOptions[5]['AlwaysUseKeystone'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone6:GetChecked() == 1) then
        MinimalArchaeologyArtifactOptions[6]['AlwaysUseKeystone'] = true;
    else
        MinimalArchaeologyArtifactOptions[6]['AlwaysUseKeystone'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone7:GetChecked() == 1) then
        MinimalArchaeologyArtifactOptions[7]['AlwaysUseKeystone'] = true;
    else
        MinimalArchaeologyArtifactOptions[7]['AlwaysUseKeystone'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone8:GetChecked() == 1) then
        MinimalArchaeologyArtifactOptions[8]['AlwaysUseKeystone'] = true;
    else
        MinimalArchaeologyArtifactOptions[8]['AlwaysUseKeystone'] = false;
    end
	
	if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone9:GetChecked() == 1) then
        MinimalArchaeologyArtifactOptions[9]['AlwaysUseKeystone'] = true;
    else
        MinimalArchaeologyArtifactOptions[9]['AlwaysUseKeystone'] = false;
    end
	
	--if (MinimalArchaeologyOptionPanel.useKeystones.usekeystone10:GetChecked() == 1) then
    --    MinimalArchaeologyArtifactOptions[10]['AlwaysUseKeystone'] = true;
    --else
    --    MinimalArchaeologyArtifactOptions[10]['AlwaysUseKeystone'] = false;
    --end
	
	MinimalArchaeology:UpdateMinArchRankBar();
end

function MinimalArchaeology:MiscOptionsToggle()
	if (MinimalArchaeologyOptionPanel.miscOptions.hideMinimap:GetChecked() == 1) then
		MinimalArchaeologyOptions['HideMinimap'] = true;
		MinimalArchaeologyMinimapButton:Hide();
    else
        MinimalArchaeologyOptions['HideMinimap'] = false;
		MinimalArchaeologyMinimapButton:Show();
    end
	
	if (MinimalArchaeologyOptionPanel.miscOptions.disableSound:GetChecked() == 1) then
		MinimalArchaeologyOptions['DisableSound'] = true;
    else
        MinimalArchaeologyOptions['DisableSound'] = false;
    end
end

function MinimalArchaeology:OpenOptions()
	MinimalArchaeologyOptionPanel.hideArtifact.hide1.text:SetText(MinimalArchaeology['artifacts'][1]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide2.text:SetText(MinimalArchaeology['artifacts'][2]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide3.text:SetText(MinimalArchaeology['artifacts'][3]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide4.text:SetText(MinimalArchaeology['artifacts'][4]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide5.text:SetText(MinimalArchaeology['artifacts'][5]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide6.text:SetText(MinimalArchaeology['artifacts'][6]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide7.text:SetText(MinimalArchaeology['artifacts'][7]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide8.text:SetText(MinimalArchaeology['artifacts'][8]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide9.text:SetText(MinimalArchaeology['artifacts'][9]['race']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide10.text:SetText(MinimalArchaeology['artifacts'][10]['race']);
	
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone1.text:SetText(MinimalArchaeology['artifacts'][1]['race']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone2.text:SetText(MinimalArchaeology['artifacts'][2]['race']);
	--MinimalArchaeologyOptionPanel.useKeystones.usekeystone3.text:SetText(MinimalArchaeology['artifacts'][3]['race']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone4.text:SetText(MinimalArchaeology['artifacts'][4]['race']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone5.text:SetText(MinimalArchaeology['artifacts'][5]['race']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone6.text:SetText(MinimalArchaeology['artifacts'][6]['race']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone7.text:SetText(MinimalArchaeology['artifacts'][7]['race']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone8.text:SetText(MinimalArchaeology['artifacts'][8]['race']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone9.text:SetText(MinimalArchaeology['artifacts'][9]['race']);
	--MinimalArchaeologyOptionPanel.useKeystones.usekeystone10.text:SetText(MinimalArchaeology['artifacts'][10]['race']);
	
	MinimalArchaeology:OptionSetCheckBoxes();
end

function MinimalArchaeology:OptionSetCheckBoxes()
	if (MinimalArchaeologyOptionPanel ~= nil) then
	MinimalArchaeologyOptionPanel.hideArtifact.hide1:SetChecked(MinimalArchaeologyHideOptions[1]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide2:SetChecked(MinimalArchaeologyHideOptions[2]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide3:SetChecked(MinimalArchaeologyHideOptions[3]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide4:SetChecked(MinimalArchaeologyHideOptions[4]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide5:SetChecked(MinimalArchaeologyHideOptions[5]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide6:SetChecked(MinimalArchaeologyHideOptions[6]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide7:SetChecked(MinimalArchaeologyHideOptions[7]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide8:SetChecked(MinimalArchaeologyHideOptions[8]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide9:SetChecked(MinimalArchaeologyHideOptions[9]['Hide']);
	MinimalArchaeologyOptionPanel.hideArtifact.hide10:SetChecked(MinimalArchaeologyHideOptions[10]['Hide']);
	
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone1:SetChecked(MinimalArchaeologyArtifactOptions[1]['AlwaysUseKeystone']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone2:SetChecked(MinimalArchaeologyArtifactOptions[2]['AlwaysUseKeystone']);
	--MinimalArchaeologyOptionPanel.useKeystones.usekeystone3:SetChecked(MinimalArchaeologyArtifactOptions[3]['AlwaysUseKeystone']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone4:SetChecked(MinimalArchaeologyArtifactOptions[4]['AlwaysUseKeystone']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone5:SetChecked(MinimalArchaeologyArtifactOptions[5]['AlwaysUseKeystone']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone6:SetChecked(MinimalArchaeologyArtifactOptions[6]['AlwaysUseKeystone']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone7:SetChecked(MinimalArchaeologyArtifactOptions[7]['AlwaysUseKeystone']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone8:SetChecked(MinimalArchaeologyArtifactOptions[8]['AlwaysUseKeystone']);
	MinimalArchaeologyOptionPanel.useKeystones.usekeystone9:SetChecked(MinimalArchaeologyArtifactOptions[9]['AlwaysUseKeystone']);
	--MinimalArchaeologyOptionPanel.useKeystones.usekeystone10:SetChecked(MinimalArchaeologyArtifactOptions[10]['AlwaysUseKeystone']);
		
	MinimalArchaeologyOptionPanel.miscOptions.hideMinimap:SetChecked(MinimalArchaeologyOptions['HideMinimap']);
	MinimalArchaeologyOptionPanel.miscOptions.disableSound:SetChecked(MinimalArchaeologyOptions['DisableSound']);
	end
end